@@ -1,4 +1,4 @@
-/* $Id: pcpserver.h,v 1.5 2017/12/12 11:43:31 nanard Exp $ */
+/* $Id: pcpserver.h,v 1.6 2018/05/08 21:28:28 nanard Exp $ */
 /* MiniUPnP project
  * Website : http://miniupnp.free.fr/
  * Author : Peter Tatrai
@@ -52,6 +52,14 @@ int ProcessIncomingPCPPacket(int s, unsigned char *msg_buff, int len,
  */
 int OpenAndConfPCPv6Socket(void);
 
+/*
+ * Send Unsolicited ANNOUNCE Message
+ */
+#ifdef ENABLE_IPV6
+void PCPSendUnsolicitedAnnounce(int * sockets, int n_sockets, int socket6);
+#else /* IPv4 only */
+void PCPSendUnsolicitedAnnounce(int * sockets, int n_sockets);
+#endif
 
 /*
  * To be called when Public IP address changed (IPv4)
